@@ -2,10 +2,8 @@
 Class to hold miscellaneous but useful decorators for our framework
 """
 import pytest
-from pytest_html import extras
 from inspect import getfullargspec
 
-
 class Wrapit():
     "Wrapit class to hold decorator functions"
 
@@ -29,7 +27,7 @@ class Wrapit():
 
         # Usage: Make this the first decorator to a method (right above the 'def function_name' line)
         # Otherwise, we cannot name the screenshot with the name of the function that called it
-        def wrapper(request, *args, **kwargs):
+        def wrapper(*args, **kwargs):
             """Original code"""
             # result = func(*args, **kwargs)
             # screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
@@ -43,17 +41,29 @@ class Wrapit():
             # If return True, only take screenshot if option -screenshot all
             # If return False, take screenshot for both -screenshot all/failonly
             # If not return boolean, skip screenshot
-            if args[0].screenshot == 'all':
-                screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
-                args[0].screenshot_counter += 1
-                args[0].save_screenshot(screenshot_name)
-                extra = extras.image(screenshot_name)
-                request.config.pytest_html.extend_html(request, "Screenshot", extra)
+            # if args[0].screenshot == 'all':
+            #     screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
+            #     args[0].screenshot_counter += 1
+            #     args[0].save_screenshot(screenshot_name)
+            # elif args[0].screenshot == 'failonly' and result is False:
+            #     screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
+            #     args[0].screenshot_counter += 1
+            #     args[0].save_screenshot(screenshot_name)
 
-            elif args[0].screenshot == 'failonly' and result is False:
+            if not result:
+                # filename = f"{func.__name__}.png"
                 screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
                 args[0].screenshot_counter += 1
                 args[0].save_screenshot(screenshot_name)
+                # code to take the screenshot
+                # base_page.save_screenshot(screenshot_name)
+                # ...
+                request = getattr(func, "request", None)
+                if request:
+                    html_report = request.config.pluginmanager.get_plugin("html")
+                    if html_report:
+                        html_report.attach_file(screenshot_name)
+
             return result
 
         return wrapper
